@@ -34,7 +34,7 @@ class ScenarioManagerFactory():
     This class manages all scenario of all scenario managers and exposes methods to look them up, read from filesystem and flush them
     """
 
-    def __init__(self):
+    def __init__(self, start_scenario_monitor: bool, start_model_monitor: bool):
         """
         Initialize object and reserve namespaces for scenario managers, monitors, scenarios and JSON file path (scenario storage)
         """
@@ -47,6 +47,9 @@ class ScenarioManagerFactory():
         self.path = ""
         self.scenario_files = []
 
+        self.start_scenario_monitor = start_scenario_monitor
+        self.start_model_monitor = start_model_monitor
+
     def __readScenario(self, filename=""):
         """
         Reads the specified JSON file and generates the scenario_manager and scenario objects
@@ -66,7 +69,6 @@ class ScenarioManagerFactory():
             parser_class = ParserFactory(filename)
 
             if parser_class:
-
                 meta_model = parser_class().parse_model(filename, silent=True)
                 model, model_dictionary = meta_model.create_model()
 
@@ -123,7 +125,7 @@ class ScenarioManagerFactory():
                 manager.load_scenarios(scen_dict=scen_dict, model_file=model_file, source=source)
 
                 # Start monitor for source file
-                if "source" in model_dictionary[scenario_manager_name].keys():
+                if self.start_model_monitor and "source" in model_dictionary[scenario_manager_name].keys():
                     if not source in self.model_monitors.keys() and os.path.isfile(source):
                         self.__add_monitor(manager.source, manager.model_file)
                     elif not os.path.isfile(manager.source):
@@ -134,7 +136,7 @@ class ScenarioManagerFactory():
                 manager.instantiate_model()
 
             ## CREATE FILE MONITOR
-            if not filename in self.file_monitors.keys():
+            if self.start_scenario_monitor and not filename in self.file_monitors.keys():
                 self.file_monitors[filename] = FileMonitor(json_file=filename,
                                                            update_func=self.__refresh_scenarios_for_json)
 
@@ -300,6 +302,7 @@ class ScenarioManagerFactory():
             log("[INFO] Killing monitoring thread for {}".format(name))
 
         self.model_monitors = {}
+        self.file_monitors = {}
 
     def create_scenario(self, filename="",
                         dictionary={}):
