@@ -1,3 +1,4 @@
+
 #                                                       /`-
 # _                                  _   _             /####`-
 # | |                                | | (_)           /########`-
@@ -137,10 +138,7 @@ class SdRunner(ScenarioRunner):
        """
 
         # Obtain simulation results
-        scenario_objects = self._run_scenarios(scenarios=scenarios,
-                                                                                                  equations=equations,
-                                                                                                  output=["frame"],
-                                                                                                  scenario_managers=scenario_managers)
+        scenario_objects = self._run_scenarios(scenarios=scenarios, equations=equations, output=["frame"], scenario_managers=scenario_managers)
 
         if len(scenario_objects.keys()) == 0:
             log("[ERROR] No scenario found for scenario_managers={} and scenario_names={}. Cancelling".format(
@@ -155,7 +153,6 @@ class SdRunner(ScenarioRunner):
 
         all_equations = [item for sublist in [list(mod.model.equations.keys()) for mod in scenario_objects.values()] for item in sublist]
         all_equations = list(dict.fromkeys(all_equations))
-
         # Generate an index {equation .: [scenario1,scenario2...], equation2: [...] }
         # We are checking which scenarios can handle which equation
         import re
